@@ -4,17 +4,13 @@
 #         Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
 #
-# $Id: Service.pm,v 1.5 2009/08/27 19:39:26 kawas Exp $
+# $Id: Service.pm,v 1.1 2006/10/13 21:51:16 senger Exp $
 #-----------------------------------------------------------------
 package MOSES::MOBY::Def::Service;
 use base qw( MOSES::MOBY::Base );
 use XML::LibXML;
 use strict;
 
-# add versioning to this module
-use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.5 $ =~ /: (\d+)\.(\d+)/;
-
 =head1 NAME
 
 MOSES::MOBY::Def::Service - a BioMoby service definition
@@ -260,7 +256,7 @@ sub toXML {
 sub _check_category {
     my ($self, $attr) = @_;
     $self->throw ('Invalid service category: ' . $self->category)
-	unless $self->category =~ /^cgi|wsdl|moby|moby\-async|post|cgi\-async$/i;
+	unless $self->category =~ /^cgi|wsdl|moby|moby\-async|post$/i;
 }
 
 1;
